# -*- coding: utf-8 -*-
"""
Calculate gunning fog readability score
"""
name = "py-readabilitiy-metrics"
__title__ = name
__version__ = '0.11.7'
__author__ = 'Carmine DiMascio'
__license__ = 'MIT'
__copyright__ = 'Copyright 2015 Carmine DiMascio'

from .readability import Readability
